@@ -59,7 +59,8 @@ class BaseMeta(type):
         else:
             cls.defined_fields = copy(cls.defined_fields)
             for base in bases:
-                cls.defined_fields |= base.defined_fields
+                if hasattr(base, 'defined_fields'):
+                    cls.defined_fields |= base.defined_fields
 
         # Define any associations set during class definition
         if not hasattr(cls, 'defined_associations'):
@@ -67,13 +68,15 @@ class BaseMeta(type):
         else:
             cls.defined_associations = deepcopy(cls.defined_associations)
             for base in bases:
-                cls.defined_associations.update(base.defined_associations)
+                if hasattr(base, 'defined_associations'):
+                    cls.defined_associations.update(base.defined_associations)
 
         if not hasattr(cls, 'callback_manager'):
             cls.callback_manager = callbacks.CallbackManager()
         else:
             cls.callback_manager = callbacks.CallbackManager(
-                    [ base.callback_manager for base in bases ] )
+                    [ base.callback_manager for base in bases 
+                        if hasattr(base, 'callback_manager') ] )
 
         # Force calling of __setattr__ for each defined attribute for special
         # attribute handling
